@@ -86,11 +86,7 @@ public:
     QString text;
 
 protected:
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    void enterEvent(QEvent *event) override;
-#else
     void enterEvent(QEnterEvent *event) override;
-#endif
     void leaveEvent(QEvent*) override;
 
 private:
